<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>ShowDesktop</name>
    <message>
        <location filename="../showdesktop.cpp" line="44"/>
        <source>Show desktop</source>
        <translation>Mostrar área de trabalho</translation>
    </message>
    <message>
        <location filename="../showdesktop.cpp" line="66"/>
        <source>Show Desktop: Global shortcut &apos;%1&apos; cannot be registered</source>
        <translation>Mostrar área de trabalho: o atalho global &apos;%1&apos; não pode ser registado</translation>
    </message>
    <message>
        <location filename="../showdesktop.cpp" line="51"/>
        <source>Show Desktop</source>
        <translation>Mostrar área de trabalho</translation>
    </message>
</context>
</TS>
